[boinc-app-seti] 01/05: New upstream version 8.00~svn3701

Gianfranco Costamagna locutusofborg at moszumanska.debian.org
Mon Sep 11 13:31:49 UTC 2017


This is an automated email from the git hooks/post-receive script.

locutusofborg pushed a commit to branch master
in repository boinc-app-seti.

commit e623477978df5ff07319fbc6a16b73babf1644ed
Author: Gianfranco Costamagna <costamagnagianfranco at yahoo.it>
Date:   Mon Sep 11 15:25:30 2017 +0200

    New upstream version 8.00~svn3701
---
 client/analyzeFuncs.cpp      |  4 ++--
 client/win-sah_config.h      | 13 ++++++++++---
 client/worker.cpp            |  9 +++++++--
 db/db_table.h                |  4 ++--
 splitter_pfb/mb_splitter.cpp | 42 ++++++++++++++++++++++++++++++++----------
 5 files changed, 53 insertions(+), 19 deletions(-)

diff --git a/client/analyzeFuncs.cpp b/client/analyzeFuncs.cpp
index a684cd4..16de55d 100644
--- a/client/analyzeFuncs.cpp
+++ b/client/analyzeFuncs.cpp
@@ -33,10 +33,10 @@
 
 #if defined(USING_XCODE) || defined(_WIN32)
 #include "version.h"
-const char *BOINC_PACKAGE_STRING="libboinc: "BOINC_VERSION_STRING;
+const char *BOINC_PACKAGE_STRING="libboinc: " BOINC_VERSION_STRING;
 #else
 #include "config.h"
-const char *BOINC_PACKAGE_STRING="libboinc: "PACKAGE_STRING;
+const char *BOINC_PACKAGE_STRING="libboinc: " PACKAGE_STRING;
 #endif
 
 #undef PACKAGE_STRING
diff --git a/client/win-sah_config.h b/client/win-sah_config.h
index efb121f..250693c 100644
--- a/client/win-sah_config.h
+++ b/client/win-sah_config.h
@@ -30,6 +30,9 @@
 #ifndef _SAH_WIN_CONFIG_H_
 #define _SAH_WIN_CONFIG_H_
 
+#if _MSC_VER ==1900
+	struct IUnknown;//R: to make clang toolchain in VS2015 happy (though it too green to be usable anyway; doesn't implement needed intrinsics)
+#endif
 #ifdef __MINGW32__
 #include <stdlib.h>
 #endif
@@ -406,7 +409,7 @@
 
 /* Define to the full name and version of this package. */
 #undef PACKAGE_STRING
-#define PACKAGE_STRING FILE_DESCRIPTION" "FILE_VERSION
+#define PACKAGE_STRING FILE_DESCRIPTION" " FILE_VERSION
 
 /* Define to the one symbol short name of this package. */
 #undef PACKAGE_TARNAME
@@ -427,8 +430,12 @@
 #elif defined(_MSC_VER)
 #if _MSC_VER == 1500
 	#define COMPILER_STRING "Visual Studio 2008/Microsoft Visual C++ 9"
+#elif _MSC_VER ==1600
+    #define COMPILER_STRING "Visual Studio 2010/Microsoft Visual C++ 10"
+#elif _MSC_VER ==1900
+    #define COMPILER_STRING "Visual Studio 2015/Microsoft Visual C++ 14"
 #else
-	#define COMPILER_STRING "Visual Studio 2010/Microsoft Visual C++ 10"
+	#define COMPILER_STRING "Visual Studio/Microsoft Visual C++"
 #endif
 #else 
 #define COMPILER_STRING "Unknown Compiler"
@@ -436,7 +443,7 @@
 #endif
 
 #ifndef CUSTOM_STRING
-#define CUSTOM_STRING "setiathome_v8 "FILE_VERSION" "COMPILER_STRING
+#define CUSTOM_STRING "setiathome_v8 " FILE_VERSION " " COMPILER_STRING
 #endif
 
 /* The size of a `long double', as computed by sizeof. */
diff --git a/client/worker.cpp b/client/worker.cpp
index 7b16c1f..dfd8389 100644
--- a/client/worker.cpp
+++ b/client/worker.cpp
@@ -182,8 +182,11 @@ void worker() {
     
     retval = seti_do_work();
     if (retval) SETIERROR(retval,"from seti_do_work() in worker()");
-
+#if 0 //R: Set for PGO
+	exit(retval);
+#else
     boinc_finish(retval);
+#endif
   }
   catch (seti_error e) {
     if (e == RESULT_OVERFLOW) {
@@ -194,7 +197,9 @@ void worker() {
         remaining=0;
         boinc_fraction_done(progress);
         checkpoint(true);      // force a checkpoint
-        boinc_finish(0);
+#if 1 //R: set 0 for PGO logging test
+		boinc_finish(0);
+#endif
 #ifdef USE_MANUAL_CALLSTACK
         call_stack.exit();
 #endif 
diff --git a/db/db_table.h b/db/db_table.h
index 937b699..fd6e6ec 100644
--- a/db/db_table.h
+++ b/db/db_table.h
@@ -240,7 +240,7 @@ std::string db_reference<T,ID_TYPE>::print(int full_subtables, int show_ids, int
     return r.print(full_subtables,show_ids,no_refs);
   } else {
     char buf[256];
-    sprintf(buf,"%"INT8_FMT,INT8_PRINT_CAST(sqlint8_t(r.id)));
+    sprintf(buf,"%" INT8_FMT,INT8_PRINT_CAST(sqlint8_t(r.id)));
     return std::string(buf);
   }
 }
@@ -251,7 +251,7 @@ std::string db_reference<T,ID_TYPE>::print_xml(int full_subtables, int show_ids,
     return r.print_xml(full_subtables,show_ids,no_refs,tag);
   } else {
     char buf[256];
-    sprintf(buf,"<id>%"INT8_FMT"</id>",INT8_PRINT_CAST(sqlint8_t(r.id)));
+    sprintf(buf,"<id>%" INT8_FMT "</id>",INT8_PRINT_CAST(sqlint8_t(r.id)));
     return std::string(buf);
   }
 }
diff --git a/splitter_pfb/mb_splitter.cpp b/splitter_pfb/mb_splitter.cpp
index 17335a4..b63177b 100644
--- a/splitter_pfb/mb_splitter.cpp
+++ b/splitter_pfb/mb_splitter.cpp
@@ -108,12 +108,14 @@ int beam;
 int pol;
 int alfa = 0; 
 int gbt = 0;
+int parkes = 0;
 int channel;
 int raw_bit_depth = 0; // bit depth of raw data (required for guppi data).  A depth of N means N real, N imag
 int samples_per_byte;  // real samples/byte
 int dumpsubband = -1;  // default to not dumping
 int dumpraw = 0;       // default to not dumping
 enum file_types {dr2, guppi};
+enum guppi_types {guppi_gbt, guppi_parkes};
 int useanalysiscfgid = 0;
 int usereceivercfgid = 0;
 int userecordercfgid = 0;
@@ -163,9 +165,9 @@ int process_command_line(int argc, char *argv[],char **tape_device,
                          int *norewind, int *startblock, int *resumetape,
                          int *nodb, int *dataclass, int *atnight,
                          int *max_wus_ondisk, char **projectdir, int *iters, 
-                         int *beam, int *pol, int *alfa, int *gbt, int *channel, 
-                         int *raw_bit_depth, int *dumpsubband, int *dumpraw,
-                         int *useanalysiscfgid, int *usereceivercfgid,
+                         int *beam, int *pol, int *alfa, int *gbt, int *parkes, 
+						 int *channel, int *raw_bit_depth, int *dumpsubband, 
+						 int *dumpraw, int *useanalysiscfgid, int *usereceivercfgid,
                          int *userecordercfgid, int *usesplittercfgid) {
 //-------------------------------------------------------------------------
   int nargs=0,i;
@@ -222,7 +224,7 @@ int process_command_line(int argc, char *argv[],char **tape_device,
 			                    char *fe=ep+1;
 			                    memset(trigger_file_path,0,sizeof(trigger_file_path));
 			                    while (isgraph(*(fe++))) trigger_file_path[fe-ep-2]=*fe ;
-                          } else if (!strncmp(argv[i],"-alfa",MAX(ep-argv[i],3))) {
+                          } else if (!strncmp(argv[i],"-alfa",MAX(ep-argv[i],4))) {
 			                    sscanf(ep+1,"%d,%d",beam,pol);
 			                    if (((*beam<0) || (*beam>6)) ||
 			                        ((*pol<0) || (*pol>1))) {
@@ -237,6 +239,13 @@ int process_command_line(int argc, char *argv[],char **tape_device,
 				                    exit(EXIT_FAILURE);
 		                        }
 			                    *gbt=1;
+                          } else if (!strncmp(argv[i],"-parkes",MAX(ep-argv[i],6))) {
+			                    sscanf(ep+1,"%d,%d",channel,pol);
+			                    if (*pol<0 || *pol>1) {
+                                    log_messages.printf(SCHED_MSG_LOG::MSG_CRITICAL,"Parkes receivers must be specified with a channel and polarization (0-1), i.e. -parkes=0,1\n");
+				                    exit(EXIT_FAILURE);
+		                        }
+			                    *parkes=1;
                           } else if (!strncmp(argv[i],"-iterations",MAX(ep-argv[i],2))) {
 			    sscanf(ep+1,"%d",iters);
 			  } else if (!strncmp(argv[i],"-startblock",MAX(ep-argv[i],2))) {
@@ -283,7 +292,11 @@ int process_command_line(int argc, char *argv[],char **tape_device,
   if (! *projectdir) return (1);
   if (! *tape_device) return (1);
   if (*gbt && !*raw_bit_depth) {
-    log_messages.printf(SCHED_MSG_LOG::MSG_CRITICAL,"GBT data requires a bit depth : -rawbitdepth=n\n", gbt);
+    log_messages.printf(SCHED_MSG_LOG::MSG_CRITICAL,"GBT data requires a bit depth : -rawbitdepth=n\n");
+    exit(EXIT_FAILURE);
+  }
+  if (*parkes && !*raw_bit_depth) {
+    log_messages.printf(SCHED_MSG_LOG::MSG_CRITICAL,"Parkes data requires a bit depth : -rawbitdepth=n\n");
     exit(EXIT_FAILURE);
   }
 
@@ -581,25 +594,34 @@ int main(int argc, char *argv[]) {
   int good_read;
   long num_blocks_read;
   int vflag;
-  int file_type = 0;        // default to dr2 for now
+  int file_type = dr2;        	// default to dr2 for now
+  int guppi_type = guppi_gbt;  	// default to guppi_gbt for now
   int beamchan;
 
   /* Process command line arguments */
   if (process_command_line(argc,argv,&tape_device,&norewind,&startblock,&resumetape,
                            &nodb,&dataclass,&atnight,&max_wus_ondisk,&projectdir,&iters,
-			               &beam,&pol,&alfa,&gbt,&channel,&raw_bit_depth,&dumpsubband,
+			               &beam,&pol,&alfa,&gbt,&parkes,&channel,&raw_bit_depth,&dumpsubband,
                            &dumpraw, &useanalysiscfgid, &usereceivercfgid, &userecordercfgid,
                            &usesplittercfgid))  {
     fprintf(stderr,"Usage: splitter tape_device -projectdir=s [-atnight] [-nodb]\n"
     "[-xml] [-gregorian] [-resumetape | -norewind | -startblock=n] [-dataclass=n]\n"
     "[-max_wus_on_disk=n] [-iterations=n] [-trigger_file_path=filename]\n"
-    "[-alfa=beam,pol] [-gbt=beam,pol -rawbitdepth=n] [-analysis_config=id] [-receiver_config=id]\n"
-    "[-recorder_config=id] [-splitter_config=id] [-dumpsubband=subband] [-dumpraw]\n");
+    "[-alfa=beam,pol | -gbt=beam,pol -rawbitdepth=n | -parkes=beam,pol -rawbitdepth=n]\n" 
+	"[-analysis_config=id] [-receiver_config=id] [-recorder_config=id] [-splitter_config=id]\n"
+    "[-dumpsubband=subband] [-dumpraw]\n");
     exit(EXIT_FAILURE);
   }
 
   if(alfa) file_type = dr2;
-  if(gbt)  file_type = guppi;
+  if(gbt) {
+	file_type = guppi;
+	guppi_type = guppi_gbt;
+  }
+  if(parkes) {
+	file_type = guppi;
+	guppi_type = guppi_parkes;
+  }
 
   // MATTL
   if (blanking_bit == SOFTWARE_BLANKING_BIT) log_messages.printf(SCHED_MSG_LOG::MSG_NORMAL,"blanking bit: %d (SOFTWARE)\n",blanking_bit);

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-boinc/boinc-app-seti.git



More information about the pkg-boinc-commits mailing list